@@ -21,7 +21,7 @@ qx.Class.define("callbackery.ui.Desktop", {
 
         var width = callbackery.data.Config.getInstance().getBaseConfig().max_width;
         if (width){
-            this.setMaxWidth(width);
+            this.setMaxWidth(parseInt(width));
         }
         this.add(callbackery.ui.Header.getInstance());
         this.add(callbackery.ui.TabView.getInstance(),{ flex: 1})
