@@ -23,14 +23,13 @@ qx.Class.define('callbackery.ui.plugin.Table', {
     members: {
         _populate: function(){
             this.setLayout(new qx.ui.layout.VBox(0));
-            this._addToolbar();
-            this._addTable();
+            this.add(this._createToolbar());
+            this.add(this._createTable(), {flex: 1});
         },
-        _addToolbar: function(){
+        _createToolbar: function(){
             var that = this;
             var cfg = this._cfg;
             var toolbar = new qx.ui.toolbar.ToolBar();
-            this.add(toolbar);
             var action = this._action = new callbackery.ui.plugin.Action(
                 cfg,qx.ui.toolbar.Button,
                 new qx.ui.layout.HBox(0),
@@ -52,9 +51,9 @@ qx.Class.define('callbackery.ui.plugin.Table', {
             toolbar.addSpacer();
             var form = this._form = new callbackery.ui.form.Auto(cfg.form,null,callbackery.ui.form.renderer.HBox);
             toolbar.add(form);
-
+	    return toolbar;
         },
-        _addTable: function(){
+        _createTable: function(){
             var cfg = this._cfg;
             var model = this._model = new callbackery.data.RemoteTableModel(cfg,this._getParentFormData);
             var table = this._table = new qx.ui.table.Table(model,{
@@ -152,7 +151,7 @@ qx.Class.define('callbackery.ui.plugin.Table', {
                         break;
                 }
             });
-            this.add(table, {flex: 1});
+            return table;
         }
     }
 });
